@@ -50,7 +50,7 @@ struct _SeahorseContext
 	GtkObject		parent;
 	
 	/*< public >*/
-	GpgmeCtx		ctx;
+	gpgme_ctx_t		ctx;
 	
 	/*< private >*/
 	SeahorseContextPrivate	*priv;
@@ -70,16 +70,25 @@ struct _SeahorseContextClass
 								 gdouble		fract);
 };
 
+GType               seahorse_context_get_type ();
+
 SeahorseContext*	seahorse_context_new			(void);
 
 void			seahorse_context_destroy		(SeahorseContext	*sctx);
 
+guint           seahorse_context_get_n_keys     (SeahorseContext    *sctx);
+
 GList*			seahorse_context_get_keys		(SeahorseContext	*sctx);
 
+guint           seahorse_context_get_n_keys_pairs   (SeahorseContext    *sctx);
+
 GList*			seahorse_context_get_key_pairs		(SeahorseContext	*sctx);
 
-SeahorseKey*		seahorse_context_get_key		(SeahorseContext	*sctx,
-								 GpgmeKey		key);
+SeahorseKey*    seahorse_context_get_key		(SeahorseContext	*sctx,
+				                				 gpgme_key_t		key);
+
+SeahorseKey*    seahorse_context_get_key_fpr    (SeahorseContext    *sctx,
+                                                 const char *fpr);
 
 void			seahorse_context_show_progress		(SeahorseContext	*sctx,
 								 const gchar		*op,
